@@ -3,4 +3,4 @@ aclocal
 rm -vf config.cache
 autoconf
 automake --add-missing
-./configure --enable-debug --enable-pam $@
+./configure --enable-pam --with-pamdir=/etc/pam.d $@
